==> pixi-0.49.0-crates.tar.xz: cargo_home/gentoo/rattler_redaction-0.1.10/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.10](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.9...rattler_redaction-v0.1.10) - 2025-04-10

### Other

- update Cargo.toml dependencies

## [0.1.9](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.8...rattler_redaction-v0.1.9) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [0.1.8](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.7...rattler_redaction-v0.1.8) - 2025-03-04

### Other

- update Cargo.toml dependencies

## [0.1.7](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.6...rattler_redaction-v0.1.7) - 2025-02-27

### Added

- Use `opendal` in `rattler-index` and add executable (#1076)

## [0.1.6](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.5...rattler_redaction-v0.1.6) - 2025-01-08

### Other

- update Cargo.toml dependencies

## [0.1.5](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.4...rattler_redaction-v0.1.5) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [0.1.4](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.3...rattler_redaction-v0.1.4) - 2024-11-30

### Other

- update Cargo.toml dependencies

## [0.1.3](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.2...rattler_redaction-v0.1.3) - 2024-11-04

### Other

- update Cargo.toml dependencies

## [0.1.2](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.1...rattler_redaction-v0.1.2) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.1.1](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.0...rattler_redaction-v0.1.1) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))

==> pixi-0.63.1-crates.tar.xz: cargo_home/gentoo/rattler_redaction-0.1.12/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.1.12](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.11...rattler_redaction-v0.1.12) - 2025-07-01

### Fixed

- *(ci)* run pre-commit-run for all files ([#1481](https://github.com/conda/rattler/pull/1481))

## [0.1.11](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.10...rattler_redaction-v0.1.11) - 2025-06-23

### Other

- update npm name ([#1368](https://github.com/conda/rattler/pull/1368))
- update readme ([#1364](https://github.com/conda/rattler/pull/1364))

## [0.1.10](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.9...rattler_redaction-v0.1.10) - 2025-04-10

### Other

- update Cargo.toml dependencies

## [0.1.9](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.8...rattler_redaction-v0.1.9) - 2025-04-04

### Other

- update Cargo.toml dependencies

## [0.1.8](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.7...rattler_redaction-v0.1.8) - 2025-03-04

### Other

- update Cargo.toml dependencies

## [0.1.7](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.6...rattler_redaction-v0.1.7) - 2025-02-27

### Added

- Use `opendal` in `rattler-index` and add executable (#1076)

## [0.1.6](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.5...rattler_redaction-v0.1.6) - 2025-01-08

### Other

- update Cargo.toml dependencies

## [0.1.5](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.4...rattler_redaction-v0.1.5) - 2024-12-17

### Other

- update Cargo.toml dependencies

## [0.1.4](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.3...rattler_redaction-v0.1.4) - 2024-11-30

### Other

- update Cargo.toml dependencies

## [0.1.3](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.2...rattler_redaction-v0.1.3) - 2024-11-04

### Other

- update Cargo.toml dependencies

## [0.1.2](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.1...rattler_redaction-v0.1.2) - 2024-09-05

### Fixed
- typos ([#849](https://github.com/conda/rattler/pull/849))

## [0.1.1](https://github.com/conda/rattler/compare/rattler_redaction-v0.1.0...rattler_redaction-v0.1.1) - 2024-08-15

### Fixed
- move more links to the conda org from conda-incubator ([#816](https://github.com/conda/rattler/pull/816))
- use conda-incubator

### Other
- change links from conda-incubator to conda ([#813](https://github.com/conda/rattler/pull/813))
- update banner ([#808](https://github.com/conda/rattler/pull/808))
